@@ -1,16 +1,23 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Dist::Zilla::Plugin::MetaProvides;
-BEGIN {
-  $Dist::Zilla::Plugin::MetaProvides::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::Plugin::MetaProvides::VERSION = '1.15000200';
-}
-
+$Dist::Zilla::Plugin::MetaProvides::VERSION = '2.000000';
 # ABSTRACT: Generating and Populating 'provides' in your META.yml
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+
+
+
+
+
+
+
+
+
 
 1;
 
@@ -18,13 +25,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::MetaProvides - Generating and Populating 'provides' in your META.yml
 
 =head1 VERSION
 
-version 1.15000200
+version 2.000000
 
 =head1 SYNOPSIS
 
@@ -209,7 +218,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric.
+This software is copyright (c) 2014 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
